// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	Lccorr.h --- lightcurve corrector class
//
//	DESCRIPTION:
//		Lightcurve 
//
//	CHANGE HISTORY:
//		AI, 2007-05-30: 1.0.0: - first version
//
//	AUTHOR:
//		A. Ibarra, Wed May 30 16:32:18 GMT 2007
//
//	REFERENCES:
//
//
//


#ifndef LCCORR_H_
#define LCCORR_H_

#include <valarray>

#include "Dal.h"

#include "Lightcurve.h"
#include "LccorrUtils.h"

class Lccorr 
{
public:
	Lccorr(double binSize);
	~Lccorr() {delete _srcLc; delete _bkgLc;};
	
	void setTimeLimits(const Column * col);
	void setTimeLimits(double startTime, double endTime);
	void createTimeGrid();
	void setSourceData(DataSet *sourceSet);
	Lightcurve* sourceData();
	
private:
	double _startTime;
	double _endTime;
	double _binSize;
	valarray<double> _timeGrid;
	Lightcurve *_srcLc;
	Lightcurve *_bkgLc;
	LccorrUtils lcUtils;
};


#endif /*LCCORR_H_*/
